<?php
namespace Pinpoint\ProductPersonalisation\Controller\Adminhtml\ImageTemplate;

use Magento\Backend\App\Action;
use Magento\Framework\App\Request\DataPersistorInterface;
use Magento\Framework\Exception\LocalizedException;

class MassDelete extends \Magento\Backend\App\Action
{
    /**
     * Authorization level of a basic admin session
     *
     * @see _isAllowed()
     */
    const ADMIN_RESOURCE = 'Pinpoint_ProductPersonalisation::templateForm';

    /**
     * @var DataPersistorInterface
     */
    protected $dataPersistor;

    /**
     * @var \Magento\Framework\Controller\Result\JsonFactory
     */
    protected $resultJsonFactory;

    /**
     * @var \Pinpoint\ProductPersonalisation\Model\ImageTemplate
     */
    protected $imageTemplate;

    /**
     * @var \Pinpoint\ProductPersonalisation\Model\ImageRow
     */
    protected $imageTemplateRow;

    /**
     * @var \Pinpoint\ProductPersonalisation\Model\ImageRowRepository
     */
    protected $imageTemplateRowRepository;

    /**
     * MassDelete constructor.
     * @param Action\Context $context
     * @param DataPersistorInterface $dataPersistor
     * @param \Magento\Framework\Controller\Result\JsonFactory $resultJsonFactory
     * @param \Pinpoint\ProductPersonalisation\Model\ImageTemplate $imageTemplate
     * @param \Pinpoint\ProductPersonalisation\Model\ImageRow $imageTemplateRow
     * @param \Pinpoint\ProductPersonalisation\Model\ImageRowRepository $imageTemplateRowRepository
     */
    public function __construct(
        Action\Context $context,
        DataPersistorInterface $dataPersistor,
        \Magento\Framework\Controller\Result\JsonFactory $resultJsonFactory,
        \Pinpoint\ProductPersonalisation\Model\ImageTemplate $imageTemplate,
        \Pinpoint\ProductPersonalisation\Model\ImageRow $imageTemplateRow,
        \Pinpoint\ProductPersonalisation\Model\ImageRowRepository $imageTemplateRowRepository
    ) {
        $this->dataPersistor = $dataPersistor;
        $this->resultJsonFactory = $resultJsonFactory;
        $this->imageTemplate = $imageTemplate;
        $this->imageTemplateRow = $imageTemplateRow;
        $this->imageTemplateRowRepository = $imageTemplateRowRepository;

        parent::__construct($context);
    }


    public function execute()
    {
        $resultJson = $this->resultJsonFactory->create();

        $imageTemplate = $this->imageTemplate;
        $imageTemplateRows = $this->imageTemplateRow;
        $data = $this->getRequest()->getParams();

        $templateIds = $this->getSelectedIds($data);

        foreach ($templateIds as $id) {
            $template = $this->imageTemplate->load($id);
            $rows = $this->imageTemplateRow->getCollection()->addFieldToFilter('parent_template_id', $template->getId())->load()->getItems();

            try {
                $templateId = $template->getId();
                $template->delete();

                foreach ($rows as $row) {
                    $row->delete();
                }
            } catch (\Exception $ex) {
                unset($ex);
            }
        }

        return $this->_redirect('product_personalisation/imagetemplates/templatelist');
    }

    /**
     * @param $request
     * @return array
     */
    protected function getSelectedIds($request)
    {
        if (!isset($request['selected'])) {
            return $this->imageTemplate->getCollection()->addFieldToFilter('template_id', ['like' => '%'.$request['filters']['template_id'].'%'])->load()->getAllIds();
        } else {
            return $request['selected'];
        }
    }
}
